@@ -18,6 +18,8 @@
 package process
 
 import (
+	"github.com/apache/skywalking-cli/internal/commands/process/estimate"
+
 	"github.com/urfave/cli/v2"
 )
 
@@ -28,5 +30,6 @@ var Command = &cli.Command{
 	Subcommands: cli.Commands{
 		ListCommand,
 		GetCommand,
+		estimate.EstimateCommand,
 	},
 }
