@@ -19,6 +19,7 @@ package ebpf
 
 import (
 	"github.com/apache/skywalking-cli/internal/commands/profiling/ebpf/create"
+	"github.com/apache/skywalking-cli/internal/commands/profiling/ebpf/keep"
 
 	"github.com/urfave/cli/v2"
 )
@@ -28,6 +29,7 @@ var Command = &cli.Command{
 	Usage: "eBPF Profiling related sub-command",
 	Subcommands: []*cli.Command{
 		create.CreateCommand,
+		keep.KeepCommand,
 		ListTaskCommand,
 		ListScheduleCommand,
 		AnalyzationCommand,
