@@ -20,6 +20,7 @@ package profiling
 import (
 	"github.com/urfave/cli/v2"
 
+	"github.com/apache/skywalking-cli/internal/commands/profiling/continuous"
 	"github.com/apache/skywalking-cli/internal/commands/profiling/ebpf"
 	"github.com/apache/skywalking-cli/internal/commands/profiling/trace"
 )
@@ -32,5 +33,6 @@ Please following sub-command to get more information.`,
 	Subcommands: []*cli.Command{
 		trace.Command,
 		ebpf.Command,
+		continuous.Command,
 	},
 }
